@@ -1,16 +1,16 @@
 #!/usr/bin/env python
 
 from argparse import ArgumentParser
-from prettytable import PrettyTable
 import paramiko
 import subprocess
 import os
 import sys
 import tarfile
-import random
-import string
 import tempfile
 import shutil
+import json
+
+from prettytable import PrettyTable
 
 from hwinfo.pci import PCIDevice
 from hwinfo.pci.lspci import *
@@ -51,7 +51,7 @@ def find_in_tarball(tarball, filename):
     tar.close()
     matches = []
     for m in members:
-        if m.name.endswith(filename):
+        if m.name.endswith(filename) and "/crash/" not in m.name:
             matches.append(m.name)
 
     if len(matches) > 1:
@@ -63,7 +63,6 @@ def find_in_tarball(tarball, filename):
 
 def read_files_from_tarball(tarball, files):
     tar = tarfile.open(tarball)
-    data = None
     tmpdir = tempfile.mkdtemp()
 
 
@@ -135,7 +134,7 @@ class Host(object):
         return self.exec_command(['cat /proc/cpuinfo'])
 
     def get_os_data(self):
-         return self.exec_command(['cat', '/etc/xensource-inventory'])
+        return self.exec_command(['cat', '/etc/xensource-inventory'])
 
     def get_os_info(self):
         rec = {}
@@ -155,11 +154,15 @@ class Host(object):
         data = self.get_dmidecode_data()
         parser = dmidecode.DmidecodeParser(data)
         rec = parser.parse()
+        #Count sockets
+        if 'socket_designation' in rec:
+            rec['socket_count'] = len(rec['socket_designation'].split(','))
+
         try:
             os_rec = self.get_os_info()
             for k, v in os_rec.iteritems():
                 rec[k] = v
-        except:
+        except Exception:
             #Ignore failures. Only supports XS right now.
             pass
 
@@ -240,7 +243,9 @@ class HostFromLogs(Host):
 
 class HostFromTarball(HostFromLogs):
 
-    def __init__(self, filename):
+    fdata = {}
+
+    def __init__(self, filename, preload=True):
         self.tarloc = filename
         pre_load_files = [
             'lspci-nnm.out',
@@ -251,7 +256,8 @@ class HostFromTarball(HostFromLogs):
             'xensource-inventory'
         ]
 
-        self._preload_files(pre_load_files)
+        if preload:
+            self._preload_files(pre_load_files)
 
     def _preload_files(self, filenames):
         paths = []
@@ -366,6 +372,29 @@ def print_system_info(host, options):
         if devices:
             print_unit("GPU Info:", tabulate_pci_recs([dev.get_rec() for dev in devices]))
 
+def export_system_info(host, options):
+    rec = {}
+
+    if 'bios' in options:
+        rec["bios"] = host.get_info()
+
+    if 'cpu' in options:
+        rec["cpu"] = host.get_cpu_info()
+
+    if 'nic' in options:
+        devices = pci_filter_for_nics(host.get_pci_devices())
+        rec["nics"] = [dev.get_rec() for dev in devices]
+
+    if 'storage' in options:
+        devices = pci_filter_for_storage(host.get_pci_devices())
+        rec["storage_controllers"] = [dev.get_rec() for dev in devices]
+
+    if 'gpu' in options:
+        devices = pci_filter_for_gpu(host.get_pci_devices())
+        rec["gpus"] = [dev.get_rec() for dev in devices]
+
+    print json.dumps(rec, indent=4, separators=(',', ': '))
+
 def main():
     """Entry Point"""
 
@@ -377,12 +406,16 @@ def main():
     parser.add_argument("-u", "--username", help="Username for remote host.")
     parser.add_argument("-p", "--password", help="Password for remote host.")
     parser.add_argument("-l", "--logs", help="Path to the directory with the logfiles.")
+    parser.add_argument("-e", "--export", action="store_true", help="Export result in JSON format.")
 
     args = parser.parse_args()
     validate_args(args)
 
     if args.logs:
-        host = HostFromLogs(args.logs)
+        if ".tar" in args.logs:
+            host = HostFromTarball(args.logs)
+        else:
+            host = HostFromLogs(args.logs)
     else:
         host = Host(args.machine, args.username, args.password)
 
@@ -395,4 +428,7 @@ def main():
     else:
         options = filter_choices
 
-    print_system_info(host, options)
+    if args.export:
+        export_system_info(host, options)
+    else:
+        print_system_info(host, options)
